@@ -17,7 +17,7 @@
 #' @md
 plot.cartogramR <- function(x, ...) {
  if  (!inherits(x, "cartogramR")) stop(paste(deparse(substitute(x)), "must be a cartogramR object"))
- x <- x$cartogram
+ x <- sf::st_geometry(x$cartogram)
  plot(x, ...)
  return(invisible(NULL))
 }
