@@ -9,10 +9,10 @@
 print.cartogramR <- function(x, ...) {
     if  (!inherits(x, "cartogramR")) stop(paste(deparse(substitute(x)), "must be a cartogramR object"))
   cat("object of class cartogramR\n")
-  cat(paste("  Distorsion of polygons contained in", x$details["initial_data_name"],"\n"))
-  cat(paste("  based on variable", x$details["initial_count_name"], "\n"))
-  cat(paste("  using", x$details["algorithm"], "\n"))
-    if (x$options$options["absrel"]==1) {
+  cat(paste("  Distorsion of polygons contained in", attr(x, "initial_data_name"),"\n"))
+  cat(paste("  based on variable", attr(x, "initial_count_name"), "\n"))
+  cat(paste("  using", attr(x, "algorithm"), "\n"))
+    if (attr(x, "options")$options["absrel"]==1) {
       critname <- "Max of (Abs) Relative Errors: "
       crit <- max(abs(residuals.cartogramR(x, type="relative error")))
       } else {
